@@ -1,6 +1,6 @@
 package Ubic::Daemon::Status;
-{
-  $Ubic::Daemon::Status::VERSION = '1.57_01';
+BEGIN {
+  $Ubic::Daemon::Status::VERSION = '1.16';
 }
 
 use strict;
@@ -15,7 +15,6 @@ sub new {
     my $class = shift;
     my $params = validate(@_, {
         pid => 1,
-        guardian_pid => 1,
     });
     return bless $params => $class;
 }
@@ -26,33 +25,23 @@ sub pid {
     return $self->{pid};
 }
 
-sub guardian_pid {
-    my $self = shift;
-    validate_pos(@_);
-    return $self->{guardian_pid};
-}
-
 
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Ubic::Daemon::Status - daemon status structure
 
 =head1 VERSION
 
-version 1.57_01
+version 1.16
 
 =head1 SYNOPSIS
 
     say $status->pid;
-    say $status->guardian_pid;
 
 =head1 METHODS
 
@@ -66,10 +55,6 @@ Constructor. Should be called from L<Ubic::Daemon> only.
 
 Get daemon's PID.
 
-=item B<< guardian_pid() >>
-
-Get guardian's PID.
-
 =back
 
 =head1 SEE ALSO
@@ -78,13 +63,14 @@ L<Ubic::Daemon> - general process daemonizator
 
 =head1 AUTHOR
 
-Vyacheslav Matyukhin <mmcleric@yandex-team.ru>
+Vyacheslav Matjukhin <mmcleric@yandex-team.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Yandex LLC.
+This software is copyright (c) 2010 by Yandex LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
